# mailfe.pl: main routine for dcbib-mailfe(1).
# $Id: mailfe.pl,v 1.3 2000/09/06 01:38:05 takepiro Exp $
# Copyright (c) TOYODA Eizi, 1998.  All rights reserved.
# see COPYING.TXT for terms of license.

	$ETCDIR = '/etc' unless $ETCDIR;
	$BINDIR = '/usr/bin' unless $BINDIR;
	$CONFIGFILE = "$ETCDIR/dcbib.conf";

while ($_ = shift) {
	/^-c$/ && ($CONFIGFILE = shift, next);
	&die("undefined commandline argument $_");
}

	&emlOpenFile($CONFIGFILE);
	%CONFIG = &emlReadHeader();

	&emlSetFile("STDIN");
	%MAILHEADER = &emlReadHeader();

	%HEADER = &emlReadHeader();

	unless ($HEADER{"from"}) {
		$HEADER{"from"} = $MAILHEADER{"sender"}
		|| $MAILHEADER{"from"}
		|| $MAILHEADER{"unixfrom"};
	}

	## quick hack:  need lock and HAITA
	$outfnam = "/tmp/dcbib-mailfe";
	&creat($outfnam);
	&emlWriteHeader($outfnam, %HEADER);
	print $outfnam "\n";
	while (<STDIN>) {
		print $outfnam $_;
	}
	close($outfnam) || &die;

	open(STDIN, "<$outfnam") || &die;
	exec "perl", "$BINDIR/dcbib-add", "-c", $CONFIGFILE;
